"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContentStoreAdapter = void 0;
const lodash_1 = __importDefault(require("lodash"));
const path_1 = __importDefault(require("path"));
const sdk_1 = require("@stackbit/sdk");
const cms_core_1 = require("@stackbit/cms-core");
const socket_service_1 = __importDefault(require("../services/socket-service"));
const schema_assets_manager_1 = require("../utils/schema-assets-manager");
const contentful_1 = require("./contentful/contentful");
const sanity_1 = __importDefault(require("./sanity/sanity"));
const git_1 = __importDefault(require("./git/git"));
const presets_service_1 = require("../services/presets-service");
class ContentStoreAdapter {
    constructor(options) {
        var _a;
        this.stackbitConfig = null;
        this.cmsType = options.cmsType;
        this.csiEnabled = (_a = options.csiEnabled) !== null && _a !== void 0 ? _a : false;
        this.webhookUrl = options.webhookUrl;
        this.workers = options.workers;
        this.rootDir = options.rootDir;
        this.projectDir = options.projectDir;
        this.appDir = options.appDir;
        this.repoUrl = options.repoUrl;
        this.repoBranch = options.repoBranch;
        this.repoPublishBranch = options.repoPublishBranch;
        this.runEnv = options.runEnv;
        this.runUid = options.runUid;
        this.logger = options.logger;
        this.userLogger = options.userLogger;
        this.localDev = options.localDev;
        this.skipPush = options.skipPush;
        this.userCommandSpawner = options.userCommandSpawner;
        this.assetIdPrefix = options.assetIdPrefix;
        this.staticAssetsFilePath = options.staticAssetsFilePath;
        this.staticAssetsPublicPath = options.staticAssetsPublicPath;
        this.staticThemeAssetsFilePath = options.staticThemeAssetsFilePath;
        this.staticThemeAssetsPublicPath = options.staticThemeAssetsPublicPath;
        this.defaultContentTypeExtensions = options.defaultContentTypeExtensions;
        this.commitAndPushChanges = options.commitAndPushChanges;
        this.devAppRestartNeeded = options.devAppRestartNeeded;
        this.contentfulAccessToken = options.contentfulAccessToken;
        this.contentfulSpaces = options.contentfulSpaces;
        this.sanityProject = options.sanityProject;
        this.sanityQuery = options.sanityQuery;
    }
    async init({ stackbitConfig }) {
        var _a, _b, _c, _d, _e;
        const runCommand = (0, cms_core_1.getCommandRunner)({
            env: (_a = this.runEnv) !== null && _a !== void 0 ? _a : {},
            uid: this.runUid
        });
        this.gitService = new cms_core_1.GitService({
            repoUrl: (_b = this.repoUrl) !== null && _b !== void 0 ? _b : '',
            repoDir: this.projectDir,
            repoBranch: (_c = this.repoBranch) !== null && _c !== void 0 ? _c : 'preview',
            repoPublishBranch: (_d = this.repoPublishBranch) !== null && _d !== void 0 ? _d : 'master',
            worker: this.workers.gitApp,
            runCommand,
            skipPush: this.skipPush,
            logger: this.logger,
            userLogger: this.userLogger
        });
        this.stackbitConfig = await this.extendStackbitConfigWithContentSources(stackbitConfig);
        if ((_e = this.stackbitConfig) === null || _e === void 0 ? void 0 : _e.contentSources) {
            this.userLogger.info('Using Content Source Interface');
            const stackbitYamlDir = this.stackbitConfig.dirPath;
            this.contentStore = new cms_core_1.ContentStore({
                logger: this.logger,
                userLogger: this.userLogger,
                localDev: this.localDev,
                staticAssetsPublicPath: this.staticAssetsPublicPath,
                webhookUrl: this.webhookUrl,
                runCommand,
                git: this.gitService,
                userCommandSpawner: this.userCommandSpawner,
                onSchemaChangeCallback: () => socket_service_1.default.notifySchemaChange(),
                onContentChangeCallback: (contentChanges) => {
                    socket_service_1.default.notifyObjectsChanged({
                        changedObjects: lodash_1.default.reduce(lodash_1.default.pick(contentChanges, ['updatedDocuments', 'updatedAssets', 'deletedDocuments', 'deletedAssets']), (changedObjects, resultItems) => {
                            changedObjects.push(...resultItems);
                            return changedObjects;
                        }, []),
                        changedScheduledActions: lodash_1.default.reduce(lodash_1.default.pick(contentChanges, ['updatedScheduledActions', 'deletedScheduledActions']), (changedObjects, resultItems) => {
                            changedObjects.push(...resultItems);
                            return changedObjects;
                        }, [])
                    });
                },
                onActionStateChangeCallback: (actionStateChange) => socket_service_1.default.notifyActionStateChange(actionStateChange),
                handleConfigAssets: async ({ models, presets }) => {
                    return (0, schema_assets_manager_1.handleSchemaAssets)({
                        models,
                        presets,
                        rootDir: this.rootDir,
                        stackbitYamlDir: stackbitYamlDir,
                        logger: this.logger,
                        userLogger: this.userLogger,
                        staticThemeAssetsPublicPath: this.staticThemeAssetsPublicPath,
                        staticThemeAssetsFilePath: this.staticThemeAssetsFilePath
                    });
                },
                devAppRestartNeeded: this.devAppRestartNeeded
            });
            await this.contentStore.init({ stackbitConfig: this.stackbitConfig });
        }
        else {
            this.userLogger.info(`Loading from ${this.cmsType || 'git'}...`);
            this.cms = this.createCms();
            await this.cms.run({ spawnRunner: this.userCommandSpawner });
        }
    }
    async destroy() {
        var _a;
        await ((_a = this.contentStore) === null || _a === void 0 ? void 0 : _a.destroy());
    }
    isContentStoreEnabled() {
        return Boolean(this.contentStore);
    }
    getGitService() {
        return this.gitService;
    }
    async onStackbitConfigChange({ stackbitConfig }) {
        if (stackbitConfig === null || stackbitConfig === void 0 ? void 0 : stackbitConfig.filePath) {
            this.userLogger.info(`reloading stackbit config from: ${path_1.default.relative(this.rootDir, stackbitConfig.filePath)}`);
        }
        this.stackbitConfig = await this.extendStackbitConfigWithContentSources(stackbitConfig);
        if (this.contentStore) {
            try {
                await this.contentStore.onStackbitConfigChange({ stackbitConfig: this.stackbitConfig });
            }
            catch (error) {
                const errorMessage = 'error loading stackbit config';
                if (error.stack) {
                    this.userLogger.error(`${errorMessage}:\n ${error.stack}`);
                }
                else if (error.message) {
                    this.userLogger.error(`${errorMessage}: ${error.message}`);
                }
                this.userLogger.error(errorMessage, { error });
            }
        }
        else if (this.cms) {
            await this.cms.restart({ spawnRunner: this.userCommandSpawner }).catch(() => { });
        }
        socket_service_1.default.notifySchemaChange();
    }
    async extendStackbitConfigWithContentSources(config) {
        var _a, _b, _c, _d, _e, _f;
        // if there is no config, or config already has contentSources, return it
        if (!config || (config === null || config === void 0 ? void 0 : config.contentSources)) {
            return config;
        }
        // if CSI enabled, and cmsType is one of the CSI supported content-sources,
        // create content-sources according to the cmsType
        const supportedContentSources = ['git', 'contentful', 'sanity'];
        const forceCSI = (!this.cmsType || supportedContentSources.includes(this.cmsType)) && this.csiEnabled;
        if (!forceCSI) {
            return config;
        }
        // for backward compatibility use ContentfulContentSource when stackbit.yaml has cmsType === 'contentful'
        if (this.cmsType === 'contentful') {
            const contentfulContentSourceModule = await importContentSourceModule('@stackbit/cms-contentful');
            const contentSources = this.contentfulSpaces.map((space) => {
                return new contentfulContentSourceModule.ContentfulContentSource({
                    spaceId: space.spaceId,
                    previewToken: space.previewToken,
                    accessToken: this.contentfulAccessToken
                });
            });
            return {
                ...config,
                contentSources
            };
        }
        // for backward compatibility use SanityContentSource when stackbit.yaml has cmsType === 'sanity'
        if (this.cmsType === 'sanity') {
            const sanityContentSourceModule = await importContentSourceModule('@stackbit/cms-sanity');
            const contentSources = [
                new sanityContentSourceModule.SanityContentSource({
                    token: (_a = this.sanityProject) === null || _a === void 0 ? void 0 : _a.token,
                    projectId: (_b = this.sanityProject) === null || _b === void 0 ? void 0 : _b.projectId,
                    dataset: ((_c = this.sanityProject) === null || _c === void 0 ? void 0 : _c.dataset) || 'production',
                    studioPath: path_1.default.join(this.appDir, ((_d = this.sanityProject) === null || _d === void 0 ? void 0 : _d.studioPath) || 'studio'),
                    studioUrl: (_e = this.sanityProject) === null || _e === void 0 ? void 0 : _e.projectUrl,
                    rootPath: this.projectDir
                })
            ];
            return {
                ...config,
                contentSources
            };
        }
        if (!this.cmsType || this.cmsType === 'git') {
            const gitContentSourceModule = await importContentSourceModule('@stackbit/cms-git');
            const result = await (0, sdk_1.loadConfigWithModelsPresetsAndValidate)({
                dirPath: this.projectDir,
                isForcedGitCSI: true
            });
            for (const error of result.errors) {
                this.userLogger.warn('error in stackbit config: ' + error.message);
            }
            const contentSources = [
                new gitContentSourceModule.GitContentSource({
                    repoUrl: this.repoUrl,
                    repoBranch: this.repoBranch,
                    rootPath: this.projectDir,
                    contentDirs: [config.pagesDir, config.dataDir].filter(Boolean),
                    assetsConfig: config.assets,
                    models: (_f = result.config) === null || _f === void 0 ? void 0 : _f.models
                })
            ];
            return {
                ...config,
                contentSources
            };
        }
        throw new Error(`no default content source for cmsType: ${this.cmsType}`);
        // for backward compatibility use ContentfulContentSource when stackbit.yaml has cmsType === 'git'
        // const gitContentSourceModule = await importContentSourceModule('@stackbit/cms-git');
        // return ...
    }
    createCms() {
        var _a, _b, _c, _d, _e, _f;
        // Remove once sanity and git-cms are implemented as ContentSourceInterface
        if (this.cmsType === 'contentful') {
            return new contentful_1.Contentful({
                accessToken: (_a = this.contentfulAccessToken) !== null && _a !== void 0 ? _a : null,
                spaces: this.contentfulSpaces,
                stackbitConfig: this.stackbitConfig,
                encodeDelimiter: '',
                rootDir: this.rootDir,
                repoDir: this.projectDir,
                appDir: this.appDir,
                staticThemeAssetsFilePath: this.staticThemeAssetsFilePath,
                staticThemeAssetsPublicPath: this.staticThemeAssetsPublicPath,
                watchForContentUpdates: true,
                onContentUpdate: () => { },
                logger: this.logger,
                userLogger: this.userLogger
            });
        }
        else if (this.cmsType === 'sanity') {
            return new sanity_1.default({
                rootDir: this.rootDir,
                repoDir: this.projectDir,
                appDir: this.appDir,
                stackbitConfig: this.stackbitConfig,
                sanityQuery: this.sanityQuery,
                encodeDelimiter: '',
                workers: this.workers,
                project: {
                    token: (_b = this.sanityProject) === null || _b === void 0 ? void 0 : _b.token,
                    projectId: (_c = this.sanityProject) === null || _c === void 0 ? void 0 : _c.projectId,
                    dataset: (_d = this.sanityProject) === null || _d === void 0 ? void 0 : _d.dataset,
                    studioPath: (_e = this.sanityProject) === null || _e === void 0 ? void 0 : _e.studioPath,
                    projectUrl: (_f = this.sanityProject) === null || _f === void 0 ? void 0 : _f.projectUrl
                },
                staticThemeAssetsFilePath: this.staticThemeAssetsFilePath,
                staticThemeAssetsPublicPath: this.staticThemeAssetsPublicPath,
                onContentUpdate: () => { },
                logger: this.logger,
                userLogger: this.userLogger
            });
        }
        else {
            return new git_1.default({
                rootDir: this.rootDir,
                repoDir: this.projectDir,
                appDir: this.appDir,
                repoUrl: this.repoUrl,
                repoBranch: this.repoBranch,
                stackbitConfig: this.stackbitConfig,
                workers: this.workers,
                assetIdPrefix: this.assetIdPrefix,
                staticAssetsFilePath: this.staticAssetsFilePath,
                staticAssetsPublicPath: this.staticAssetsPublicPath,
                staticThemeAssetsFilePath: this.staticThemeAssetsFilePath,
                staticThemeAssetsPublicPath: this.staticThemeAssetsPublicPath,
                defaultContentTypeExtensions: this.defaultContentTypeExtensions,
                commitAndPushChanges: this.commitAndPushChanges,
                logger: this.logger,
                userLogger: this.userLogger
            });
        }
    }
    async keepAlive() {
        if (this.contentStore) {
            this.contentStore.keepAlive().catch((error) => {
                this.logger.error('keepAlive error', { error });
            });
        }
        else if (this.cms) {
            lodash_1.default.invoke(this.cms, 'keepAlive');
        }
        else {
            throw new Error('Content source plugin missing required method: keepAlive');
        }
    }
    async handleFileChanges(filePaths) {
        if (!filePaths.length) {
            this.logger.debug('no changes');
            return {
                schemaChanged: false
            };
        }
        let schemaChanged = false;
        if (this.contentStore) {
            const updatedFiles = filePaths.map((filePath) => path_1.default.relative(this.appDir, path_1.default.join(this.projectDir, filePath)));
            // schemaChanged and contentChanged events are handled within content-store
            await this.contentStore.onFilesChange(updatedFiles);
        }
        else if (this.cms) {
            const pullResult = await this.cms
                .postPull(filePaths.map((filePath) => path_1.default.join(this.projectDir, filePath)), {
                spawnRunner: this.userCommandSpawner
            })
                .catch((err) => {
                this.logger.debug('Error in postPull', { err });
                throw err;
            });
            schemaChanged = !!(pullResult === null || pullResult === void 0 ? void 0 : pullResult.schemaChanged);
        }
        if (schemaChanged) {
            socket_service_1.default.notifySchemaChange();
        }
        return { schemaChanged };
    }
    getLocales() {
        if (this.contentStore) {
            return this.contentStore.getLocales();
        }
        else if (this.cms) {
            return lodash_1.default.result(this.cms, 'getLocales');
        }
        else {
            throw new Error('Content source plugin missing required method: getLocales');
        }
    }
    getPresets({ locale } = {}) {
        if (this.contentStore) {
            return this.contentStore.getPresets({ locale });
        }
        else if (this.cms) {
            return lodash_1.default.result(this.cms, 'getPresets', {});
        }
        else {
            throw new Error('Content source plugin missing required method: getPresets');
        }
    }
    getModelsByContentSourceType({ locale } = {}) {
        if (this.contentStore) {
            // contentStore models already localized to default locale
            return this.contentStore.getModels();
        }
        else if (this.cms) {
            const schemaKey = this.cms.getSchemaKey();
            const mappedModels = this.cms.getMappedModels(locale);
            return { [schemaKey]: mappedModels };
        }
        else {
            throw new Error('Content source plugin missing required method: getModelsByContentSourceType');
        }
    }
    getContentSourceEnvironmentForContentSourceTypeAndId({ srcProjectId, srcType }) {
        if (this.contentStore) {
            return this.contentStore.getContentSourceEnvironment({ srcProjectId, srcType });
        }
        else if (this.cms) {
            return this.cms.getEnvironmentForProjectId(srcProjectId);
        }
        else {
            throw new Error('Content source plugin missing required method: getContentSourceEnvironmentForContentSourceTypeAndId');
        }
    }
    getContentSourceTypes() {
        var _a, _b, _c;
        return lodash_1.default.uniq((_c = (_b = (_a = this.stackbitConfig) === null || _a === void 0 ? void 0 : _a.contentSources) === null || _b === void 0 ? void 0 : _b.map((source) => source.getContentSourceType())) !== null && _c !== void 0 ? _c : []);
    }
    getContentSourceMeta() {
        if (this.contentStore) {
            return this.contentStore.getContentSourceMeta();
        }
        return [];
    }
    async getGlobalActions(data) {
        if (this.contentStore) {
            return this.contentStore.getGlobalActions(data);
        }
        return [];
    }
    async getCustomActions(data) {
        if (this.contentStore) {
            return this.contentStore.getCustomActions(data);
        }
        return [];
    }
    async runCustomAction(data) {
        if (this.contentStore) {
            return this.contentStore.runCustomAction(data);
        }
    }
    getAssetSources() {
        if (!this.contentStore) {
            return [];
        }
        return this.contentStore.getAssetSources();
    }
    async hasAccess(data) {
        if (this.contentStore) {
            return this.contentStore.hasAccess(data !== null && data !== void 0 ? data : {});
        }
        else if (this.localDev) {
            // we shouldn't reach this point because when content store isn't
            // enabled hasAccess would be handled by the API.
            return {
                hasConnection: true,
                hasPermissions: true,
                contentSources: []
            };
        }
        throw new Error('Content source plugin missing required method: hasAccess');
    }
    hasChanges({ documents }) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: hasChanges');
        }
        return this.contentStore.hasChanges({ documents });
    }
    getSiteMapEntries(options) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: getSiteMapEntries');
        }
        return this.contentStore.getSiteMapEntries(options);
    }
    getTreeViews() {
        if (!this.contentStore) {
            throw new Error('not implemented');
        }
        return this.contentStore.getTreeViews();
    }
    getSiteMapEntriesForDocument(options) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: getSiteMapEntriesForDocument');
        }
        return this.contentStore.getSiteMapEntriesForDocument(options);
    }
    getDocument({ srcDocumentId, srcProjectId, srcType }) {
        if (this.contentStore) {
            return this.contentStore.getDocument({ srcDocumentId, srcProjectId, srcType });
        }
        else if (this.cms) {
            const encodingResult = this.cms.getEncodingResult();
            const fieldData = lodash_1.default.get(encodingResult, 'fieldData');
            const document = lodash_1.default.find(fieldData, { srcObjectId: srcDocumentId, srcProjectId: srcProjectId });
            if (!document) {
                return;
            }
            if (document.type !== 'object') {
                return;
            }
            return {
                ...document,
                getPreview: () => ({ previewTitle: document.srcObjectLabel }),
                type: 'document'
            };
        }
    }
    getDocumentsByContext({ context, srcProjectId, srcType }) {
        if (this.contentStore) {
            return this.contentStore.getDocumentsByContext({ context, srcProjectId, srcType });
        }
        return [];
    }
    getDocuments({ locale }) {
        if (this.contentStore) {
            return this.contentStore.getDocuments({ locale });
        }
        else if (this.cms) {
            const encodingResult = this.cms.getEncodingResult();
            const fieldData = lodash_1.default.get(encodingResult, 'fieldData');
            return lodash_1.default.values(fieldData)
                .filter((object) => object.type === 'object')
                .map(({ type, ...rest }) => ({
                type: 'document',
                getPreview: () => ({ previewTitle: rest.srcObjectLabel }),
                ...rest
            }));
        }
        else {
            throw new Error('Content source plugin missing required method: getDocuments');
        }
    }
    getAssets({ locale }) {
        if (this.contentStore) {
            return this.contentStore.getAssets({ locale });
        }
        else if (this.cms) {
            const encodingResult = this.cms.getEncodingResult();
            const fieldData = lodash_1.default.get(encodingResult, 'fieldData');
            return lodash_1.default.values(fieldData)
                .filter((object) => object.type === 'image' || object.type === 'file')
                .map(({ type, fields, ...rest }) => ({
                type: 'asset',
                ...rest,
                fields: {
                    title: fields.title,
                    file: {
                        type: 'assetFile',
                        url: fields.url
                    }
                }
            }));
        }
        else {
            throw new Error('Content source plugin missing required method: getAssets');
        }
    }
    getAssetFilePath(url) {
        var _a;
        const assets = this.getAssets({});
        const matchingAsset = assets.find((asset) => {
            if (asset.fields.file.localized) {
                return Object.values(asset.fields.file.locales).find((locale) => {
                    return locale.url === url;
                });
            }
            return asset.fields.file.url === url;
        });
        if (matchingAsset) {
            if (matchingAsset.fields.file.localized) {
                for (const locale in matchingAsset.fields.file.locales) {
                    return (_a = matchingAsset.fields.file.locales[locale]) === null || _a === void 0 ? void 0 : _a.fileName;
                }
                return undefined;
            }
            return matchingAsset.fields.file.fileName;
        }
    }
    getLocalizedApiObjects({ locale, objectIds }) {
        if (this.contentStore) {
            return this.contentStore.getLocalizedApiObjects({ locale, objectIds });
        }
        else if (this.cms) {
            let fieldData = this.cms.getLocalizedFieldData(locale);
            if (!fieldData) {
                return [];
            }
            if (objectIds) {
                fieldData = lodash_1.default.pick(fieldData, objectIds);
            }
            return Object.values(fieldData);
        }
        else {
            throw new Error('Content source plugin missing required method: getLocalizedApiObjects');
        }
    }
    async createPreset({ dir, presetParams, preset, user }) {
        var _a, _b;
        if ((_a = this.contentStore) === null || _a === void 0 ? void 0 : _a.usesContentSourcePresets()) {
            await this.contentStore.createPreset({ preset, thumbnailAsset: presetParams.thumbnail, user });
            return {
                files: [],
                preset
            };
        }
        else {
            const result = await (0, presets_service_1.savePreset)(dir, presetParams, preset, this.logger);
            const changeLog = result.files.map((filePath) => ({
                filePath: path_1.default.join(dir, filePath),
                description: 'added preset: ' + preset.label
            }));
            if (user) {
                await ((_b = this.commitAndPushChanges) === null || _b === void 0 ? void 0 : _b.call(this, changeLog, user));
            }
            return result;
        }
    }
    async deletePreset({ dir, presetId, user }) {
        var _a, _b;
        if ((_a = this.contentStore) === null || _a === void 0 ? void 0 : _a.usesContentSourcePresets()) {
            await this.contentStore.deletePreset({ presetId, user });
            return {
                changes: [],
                filesRemoved: []
            };
        }
        else {
            const filesRemoved = await (0, presets_service_1.deletePreset)(dir, presetId, this.logger);
            const changeLog = filesRemoved.map((filePath) => ({
                filePath: path_1.default.join(dir, filePath),
                description: 'removed preset'
            }));
            if (user) {
                await ((_b = this.commitAndPushChanges) === null || _b === void 0 ? void 0 : _b.call(this, changeLog, user));
            }
            return {
                changes: changeLog,
                filesRemoved: filesRemoved
            };
        }
    }
    async createDocument(data) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: createDocument');
        }
        return this.contentStore.createDocument(data);
    }
    async createAndLinkDocument(data) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: createAndLinkDocument');
        }
        return this.contentStore.createAndLinkDocument(data);
    }
    async uploadAndLinkAsset(data) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: uploadAndLinkAsset');
        }
        return this.contentStore.uploadAndLinkAsset(data);
    }
    async duplicateDocument(data) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: duplicateDocument');
        }
        return this.contentStore.duplicateDocument(data);
    }
    async updateDocument(data) {
        var _a;
        if (!((_a = this.contentStore) === null || _a === void 0 ? void 0 : _a.updateDocument)) {
            throw new Error('Content source plugin missing required method: updateDocument');
        }
        return this.contentStore.updateDocument(data);
    }
    async deleteDocument(data) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: deleteDocument');
        }
        return this.contentStore.deleteDocument(data);
    }
    async getScheduledActions() {
        var _a;
        if (!((_a = this.contentStore) === null || _a === void 0 ? void 0 : _a.getScheduledActions)) {
            throw new Error('Content source plugin missing required method: getScheduledActions');
        }
        const scheduledActions = this.contentStore.getScheduledActions();
        return { scheduledActions };
    }
    async createScheduledAction(data) {
        var _a;
        if (!((_a = this.contentStore) === null || _a === void 0 ? void 0 : _a.createScheduledAction)) {
            throw new Error('Content source plugin missing required method: createScheduledAction');
        }
        return this.contentStore.createScheduledAction(data);
    }
    async cancelScheduledAction(data) {
        var _a;
        if (!((_a = this.contentStore) === null || _a === void 0 ? void 0 : _a.cancelScheduledAction)) {
            throw new Error('Content source plugin missing required method: cancelScheduledAction');
        }
        return this.contentStore.cancelScheduledAction(data);
    }
    async updateScheduledAction(data) {
        var _a;
        if (!((_a = this.contentStore) === null || _a === void 0 ? void 0 : _a.updateScheduledAction)) {
            throw new Error('Content source plugin missing required method: updateScheduledAction');
        }
        return this.contentStore.updateScheduledAction(data);
    }
    async searchDocuments(data) {
        var _a;
        if (this.contentStore) {
            return this.contentStore.searchDocuments(data);
        }
        if (this.cms) {
            const { locale } = data;
            const documents = this.getDocuments({ locale });
            const schema = (_a = this.getModelsByContentSourceType({ locale })) !== null && _a !== void 0 ? _a : {};
            return cms_core_1.searchUtils.searchDocuments({
                ...data,
                documents,
                schema
            });
        }
        throw new Error('Content source plugin missing required method: searchDocuments');
    }
    async getDocumentVersions(data) {
        var _a;
        if (!((_a = this.contentStore) === null || _a === void 0 ? void 0 : _a.getDocumentVersions)) {
            throw new Error('Content source plugin missing required method: getDocumentVersions');
        }
        return this.contentStore.getDocumentVersions(data);
    }
    async getDocumentForVersion(data) {
        var _a;
        if (!((_a = this.contentStore) === null || _a === void 0 ? void 0 : _a.getDocumentForVersion)) {
            throw new Error('Content source plugin missing required method: getDocumentForVersion');
        }
        return this.contentStore.getDocumentForVersion(data);
    }
    async validateDocuments(data) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: validateDocuments');
        }
        return this.contentStore.validateDocuments(data);
    }
    async publishDocuments(data) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: publishDocuments');
        }
        return this.contentStore.publishDocuments(data);
    }
    async getApiAssets(data = {}) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: getApiAssets');
        }
        return this.contentStore.getApiAssets(data);
    }
    async getApiDocuments(data = {}) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: getApiDocuments');
        }
        return this.contentStore.getApiDocuments(data);
    }
    async uploadAssets({ srcType, srcProjectId, assets, locale, user }) {
        if (this.contentStore) {
            return this.contentStore.uploadAssets({
                srcProjectId,
                srcType,
                assets,
                locale,
                user
            });
        }
        else if (this.cms && this.cms instanceof git_1.default) {
            return this.cms.uploadAssets(assets, user);
        }
        else {
            throw new Error('Content source plugin missing required method: uploadAssets');
        }
    }
    onWebhook(data) {
        if (!this.contentStore) {
            throw new Error('Content source plugin missing required method: onWebhook');
        }
        return this.contentStore.onWebhook(data);
    }
    getObject_deprecated({ objectId, projectId }) {
        // This method is specific to git-cms and called from API for git-cms only
        // Remove once git-cms is implemented as ContentSourceInterface
        if (this.cms && this.cms instanceof git_1.default) {
            return this.cms.getObject(objectId, projectId);
        }
        else {
            throw new Error('This method should never be called when using content source plugin');
        }
    }
    async listAssets_deprecated(filterParams) {
        // This method is specific to git-cms and called from API for git-cms only
        // Remove once git-cms is implemented as ContentSourceInterface
        if (this.cms && this.cms instanceof git_1.default) {
            return this.cms.listAssets(filterParams);
        }
        else {
            throw new Error('This method should never be called when using content source plugin');
        }
    }
    async getAssets_deprecated(data = {}) {
        // This method is specific to git-cms and called from API for git-cms only
        // Remove once git-cms is implemented as ContentSourceInterface
        if (this.cms && this.cms instanceof git_1.default) {
            const pageId = data.pageId || 1;
            const result = await this.cms.listAssets(data);
            return {
                data: result.assets,
                meta: {
                    nextPage: pageId < result.meta.totalPages ? pageId + 1 : null
                }
            };
        }
        else {
            throw new Error('This method should never be called when using content source plugin');
        }
    }
    async uploadAsset_deprecated({ url, fileName, user }) {
        // This method is specific to git-cms and called from API for git-cms only
        // Remove once git-cms is implemented as ContentSourceInterface
        if (this.cms && this.cms instanceof git_1.default) {
            return this.cms.uploadAsset({ url, fileName, user, data: null });
        }
        else {
            throw new Error('This method should never be called when using content source plugin');
        }
    }
    async createObject_deprecated(data) {
        // This method is specific to git-cms and called from API for git-cms only
        // Remove once git-cms is implemented as ContentSourceInterface
        if (this.cms && this.cms instanceof git_1.default) {
            return this.cms.createObject(data);
        }
        else {
            throw new Error('This method should never be called when using content source plugin');
        }
    }
    async duplicateObject_deprecated(data) {
        // This method is specific to git-cms and called from API for git-cms only
        // Remove once git-cms is implemented as ContentSourceInterface
        if (this.cms && this.cms instanceof git_1.default) {
            return this.cms.duplicateObject(data);
        }
        else {
            throw new Error('This method should never be called when using content source plugin');
        }
    }
    async updateObject_deprecated(data) {
        // This method is specific to git-cms and called from API for git-cms only
        // Remove once git-cms is implemented as ContentSourceInterface
        if (this.cms && this.cms instanceof git_1.default) {
            return this.cms.updateObject(data.changedFields, data.user);
        }
        else {
            throw new Error('This method should never be called when using content source plugin');
        }
    }
    async updateObject_api_deprecated(objectId, projectId, object, user) {
        // This method is specific to git-cms and called from API for git-cms only
        // Remove once git-cms is implemented as ContentSourceInterface
        if (this.cms && this.cms instanceof git_1.default) {
            return this.cms.updateObject_api(objectId, projectId, object, user);
        }
        else {
            throw new Error('This method should never be called when using content source plugin');
        }
    }
    async deleteObject_deprecated(data) {
        // This method is specific to git-cms and called from API for git-cms only
        // Remove once git-cms is implemented as ContentSourceInterface
        if (this.cms && this.cms instanceof git_1.default) {
            return this.cms.deleteObject(data.srcObjectId, data.user);
        }
        else {
            throw new Error('This method should never be called when using content source plugin');
        }
    }
}
exports.ContentStoreAdapter = ContentStoreAdapter;
async function importContentSourceModule(packageName) {
    let modulePath;
    try {
        modulePath = require.resolve(packageName);
    }
    catch (error) {
        throw new Error(`can not find ${packageName} package, please add it as a devDependency by running "npm i ${packageName} --save-dev"`);
    }
    let module;
    try {
        module = await Promise.resolve().then(() => __importStar(require(modulePath)));
    }
    catch (error) {
        throw new Error(`could not load ${packageName} module, error: ${error.message}`);
    }
    return module;
}
//# sourceMappingURL=content-store-adapter.js.map