import _ from 'lodash';
import { ContentStoreTypes } from '@stackbit/cms-core';
import { Logger } from '@stackbit/types';
import { Config } from '@stackbit/sdk';
import { PresetParams } from '../services/presets-service';
import { CommitAndPushChanges, ContentStoreAdapter } from '../cms/content-store-adapter';
import type { CollectionItem, CollectionItemWithModel, PageModel, SiteMap } from '../types';
export interface EditorOptions {
    contentStoreAdapter: ContentStoreAdapter;
    stackbitConfig: Config | null;
    logger: Logger;
    userLogger: Logger;
    stackbitUrlPathField: string;
    staticAssetsPublicPath?: string;
    commitAndPushChanges?: CommitAndPushChanges;
}
interface ReferencedItem {
    srcType: string;
    srcProjectId: string;
    srcDocumentId: string;
    count: number;
}
declare type ReferenceMap = Record<string, Record<string, Record<string, ReferencedItem[]>>>;
export default class Editor {
    private readonly contentStoreAdapter;
    private readonly logger;
    private readonly userLogger;
    private readonly stackbitUrlPathField;
    private readonly staticAssetsPublicPath?;
    private readonly commitAndPushChanges?;
    private stackbitConfig;
    constructor(options: EditorOptions);
    onStackbitConfigChange({ stackbitConfig }: {
        stackbitConfig: Config | null;
    }): void;
    buildUrlForPage(pageModel: PageModel, document: ContentStoreTypes.Document, locale?: string, urlPathTemplateParams?: Record<string, any>): string | null;
    getSchema({ locale }: {
        locale?: string;
    }): Promise<_.Dictionary<any>>;
    getUrl(srcDocumentId: string, srcProjectId: string, srcType: string, locale?: string): Promise<string | null>;
    getPageModels(options?: {
        forSchema?: boolean;
    }): PageModel[];
    getSiteMap({ locale }: {
        locale?: string;
    }): Promise<SiteMap>;
    getSiteMap_deprecated({ locale }: {
        locale?: string;
    }): Promise<SiteMap>;
    populateReferenceLabels(objects: ContentStoreTypes.APIObject[], documentMap: Record<string, ContentStoreTypes.Document | ContentStoreTypes.Asset>, locale?: string): void;
    getObjects({ objectIds, locale }: {
        objectIds?: string[];
        locale?: string;
    }): Promise<{
        objects: ContentStoreTypes.APIObject[];
    }>;
    getObjectsWithAnnotations({ annotationTree, clientAnnotationErrors, resolveAllReferences, locale, reportAllErrors }: {
        annotationTree: any;
        clientAnnotationErrors: any;
        resolveAllReferences?: boolean;
        locale?: string;
        reportAllErrors: boolean;
    }): Promise<{
        objects: any;
        pathMap: {};
        errors: any[];
    }>;
    getReferenceMap(documents: (ContentStoreTypes.Document | ContentStoreTypes.APIDocumentObject | ContentStoreTypes.Asset)[]): ReferenceMap;
    getCollections({ locale }: {
        locale?: string;
    }): Promise<{
        collections: {
            srcType: string;
            srcProjectId: string;
            srcModelName: string;
            srcModelLabel?: string;
            objects: Omit<CollectionItem, 'srcProjectId' | 'srcType'>[];
        }[];
        styleObjectId: string | null;
    }>;
    createPreset(dir: string, fieldDataPath: string[], presetParams: PresetParams, dryRun: boolean, user?: ContentStoreTypes.User): Promise<{
        files: string[];
        preset: import("@stackbit/sdk").Preset;
    }>;
    deletePreset(dir: string, presetId: string, user?: ContentStoreTypes.User): Promise<{
        changes: {
            filePath: string;
            description: string;
        }[];
        filesRemoved: string[];
    }>;
    searchDocuments(data: {
        query?: string;
        models: Array<{
            srcProjectId: string;
            srcType: string;
            modelName: string;
        }>;
        locale?: string;
        filter: ContentStoreTypes.SearchFilter;
    }): Promise<{
        total: number;
        items: CollectionItemWithModel[];
    }>;
    getDocumentVersions(data: {
        srcType: string;
        srcProjectId: string;
        documentId: string;
        locale?: string;
    }): Promise<{
        versions: ContentStoreTypes.APIDocumentVersion[];
    }>;
    getDocumentForVersion(data: {
        srcType: string;
        srcProjectId: string;
        documentId: string;
        versionId: string;
        locale?: string;
    }): Promise<{
        version: ContentStoreTypes.APIDocumentVersionWithDocument;
    }>;
}
export {};
//# sourceMappingURL=editor.d.ts.map